%define dev		pre
%define subrel	1
%define rel		1
Name:			nanovna-saver
Version:		0.3.9
Release:		%mkrel %{?dev:0.%{dev}.}%{rel}
Summary:		Connects to a NanoVNA to display, manipulate and save data
Group:			Communications/Radio
License:		GPLv3
Url:			https://github.com/mihtjel/nanovna-saver
Source0:		https://github.com/mihtjel/%{name}/archive/v%{version}%{?dev:-%{dev}}/%{name}-%{version}%{?dev:-%{dev}}.tar.gz

BuildRequires:	python3-serial
BuildRequires:	python3-qt5
BuildRequires:	python3-numpy
BuildRequires:	python-pip

Requires:	python3-qt5-core
Requires:	python3-qt5-gui
Requires:	python3-qt5-widgets
Requires(pre):	shadow-utils

BuildArch:		noarch

%description
A multi-platform tool to save Touchstone files from the NanoVNA. 
Sweep frequency spans in segments to gain more than 101 data points,
and display and analyze the resulting data.

Current features:
*   Reading data from a NanoVNA
*   Splitting a frequency range into multiple segments to increase resolution
    (tried up to >10k points)
*   Zoom into frequency displays to examine details
*   Averaging data for better results particularly at higher frequencies
*   Displaying data on multiple chart types, such as Smith, LogMag, Phase and
    VSWR-charts, for both S11 and S21
*   Displaying markers, and the impedance, VSWR, Q, equivalent
    capacitance/inductance etc. at these locations
*   Displaying customizable frequency bands as reference, for example amateur
    radio bands
*   Exporting and importing 1-port and 2-port Touchstone files
    TDR function (measurement of cable length)
*   Display of both an active and a reference trace
*   Live updates of data from the NanoVNA, including for multi-segment sweeps
*   In-application calibration, including compensation for non-ideal 
    calibration standards
*   Customizable display options, including "dark mode"
*   Exporting images of plotted values

%pre
usermod -G dialout -a $(users|cut -d' ' -f1) ||:

%prep
%autosetup -p1 -n %{name}-%{version}%{?dev:-%{dev}}

%build
%py3_build

%install
%{__python3} setup.py install --root=%{buildroot} --skip-build

# Make binary lower case
mv %{buildroot}%{_bindir}/NanoVNASaver %{buildroot}%{_bindir}/%{name}

# Desktop file
cat>%{name}.desktop<<EOF
[Desktop Entry]
Name=NanoVNA-Saver
GenericName=NanoVNA-Saver
Exec=%{name}
Icon=%{name}
Terminal=false
Type=Application
Categories=Science;Engineering;Electronics;
Version=1.0
Comment=Connect to NanoVNA
EOF

desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{name}.desktop

mkdir -p %{buildroot}%{_iconsdir}
cp -f icon_48x48.png %{buildroot}%{_iconsdir}/%{name}.png

cat > README.urpmi <<EOF
You will need to log out and log back in to your system
after installing NanoVNA-Saver before using it for the
first time.

Then connect your NanoVNA to a USB port and switch it on
before running NanoVNA-Saver from the menu.

It is located under the 'Sciences' section of the main menu.
EOF

%files
%doc README.urpmi
%{_bindir}/%{name}
%{python3_sitelib}/NanoVNASaver/*
%{python3_sitelib}/NanoVNASaver-*
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/%{name}.png


%changelog
* Tue Mar 16 2021 barjac <barjac> 0.3.9-0.pre.1.1.mga8
+ Revision: 1703984
- Add missing requires
- Fixes Mga#28605 (nanovna-saver fails to start)

* Sun Jan 03 2021 barjac <barjac> 0.3.9-0.pre.1.mga8
+ Revision: 1668375
- new version 0.3.9-pre

* Sat Oct 10 2020 barjac <barjac> 0.3.8-0.pre.2.mga8
+ Revision: 1633105
- allow python-scipy 1.5
- upstream bug https://github.com/NanoVNA-Saver/nanovna-saver/issues/332
- re-format %%description

* Wed Aug 26 2020 barjac <barjac> 0.3.8-0.pre.1.mga8
+ Revision: 1619055
- new version 0.3.8-pre
- modify spec to allow pre and rc versions

* Tue Jul 14 2020 barjac <barjac> 0.3.6-1.mga8
+ Revision: 1605833
- new version 0.3.6

* Sun Jul 05 2020 barjac <barjac> 0.3.4-1.mga8
+ Revision: 1602066
- new version 0.3.4

* Tue Jun 30 2020 barjac <barjac> 0.3.3-1.mga8
+ Revision: 1600793
- new version 0.3.3

* Tue Jun 30 2020 barjac <barjac> 0.3.2-1.mga8
+ Revision: 1600559
- new version 0.3.2

* Wed Feb 19 2020 umeabot <umeabot> 0.2.2-2.mga8
+ Revision: 1543041
- Mageia 8 Mass Rebuild

* Sun Jan 12 2020 barjac <barjac> 0.2.2-1.mga8
+ Revision: 1477629
- new version 0.2.2

* Sat Jan 04 2020 barjac <barjac> 0.2.1-0.1.mga8
+ Revision: 1476044
- new version 0.2.1
- added new files

* Tue Nov 12 2019 barjac <barjac> 0.2.0-1.mga8
+ Revision: 1459693
- new version 0.2.0
- spec tidy
- add line to description

* Tue Nov 05 2019 barjac <barjac> 0.1.5-1.mga8
+ Revision: 1458267
- new version 0.1.5
- remove patch fixed upstream

* Wed Oct 23 2019 barjac <barjac> 0.1.4-1.mga8
+ Revision: 1455371
- new version 0.1.4

* Tue Oct 22 2019 barjac <barjac> 0.1.3-2.mga8
+ Revision: 1455080
- Use upstream icon
- remove some white space

* Sun Oct 20 2019 barjac <barjac> 0.1.3-1.mga8
+ Revision: 1454742
- new package

